@@ -1,9 +1,10 @@
-from abc import ABC, abstractmethod
+from abc import abstractmethod
 from typing import Any, Dict, List, Optional
 
 from pydantic.main import BaseModel
 
-from obsei.analyzer.text_analyzer import AnalyzerResponse
+from obsei.analyzer.base_analyzer import AnalyzerResponse
+from obsei.workflow.base_store import BaseStore
 
 
 class Convertor(BaseModel):
@@ -33,10 +34,22 @@ class BaseSinkConfig(BaseModel):
         arbitrary_types_allowed = True
 
 
-class BaseSink(ABC):
-    def __init__(self, convertor: Convertor = Convertor()):
-        self.convertor = convertor
+class BaseSink(BaseModel):
+    convertor: Optional[Convertor] = None
+    store: Optional[BaseStore] = None
+
+    def __init__(self, **data: Any):
+        super().__init__(**data)
+        self.convertor = self.convertor or Convertor()
 
     @abstractmethod
-    def send_data(self, analyzer_responses: List[AnalyzerResponse], config: BaseSinkConfig):
+    def send_data(
+        self,
+        analyzer_responses: List[AnalyzerResponse],
+        config: BaseSinkConfig,
+        **kwargs
+    ):
         pass
+
+    class Config:
+        arbitrary_types_allowed = True
